@@ -280,7 +280,8 @@ mod tests {
         #[values(false, true)] resolve_symlinks: bool,
     ) {
         let opts = Opts { cmd, hook, echo, resolve_symlinks };
-        let source = Powershell(&opts).render().unwrap();
+        let mut source = "Set-StrictMode -Version latest\n".to_string();
+        Powershell(&opts).render_into(&mut source).unwrap();
 
         Command::new("pwsh")
             .args(&["-NoLogo", "-NonInteractive", "-NoProfile", "-Command", &source])
@@ -333,8 +334,12 @@ mod tests {
         let mut source = Xonsh(&opts).render().unwrap();
         source.push('\n');
 
+        let tempdir = tempfile::tempdir().unwrap();
+        let tempdir = tempdir.path().to_str().unwrap();
+
         Command::new("pylint")
             .args(&["--from-stdin", "zoxide"])
+            .env("HOME", tempdir)
             .write_stdin(source)
             .assert()
             .success()
@@ -398,7 +403,7 @@ mod tests {
         let source = Zsh(&opts).render().unwrap();
 
         Command::new("zsh")
-            .args(&["-c", &source, "--no-rcs"])
+            .args(&["-c", &source, "--no-globalrcs", "--no-rcs"])
             .assert()
             .success()
             .stdout("")
